==> lsx-0.1.2.tar.gz: lsx-0.1.2/lsx/docs/readme.md <==
# Lishixian Library
Contain 92 functions.


## About
- __Author:__ Lishixian
- __QQ:__ 11313213
- __Email:__ lsx7@sina.com
- __Github:__ https://github.com/znsoooo/lishixian
- __License:__ MIT License. Copyright (c) 2022 Lishixian (znsoooo). All Rights Reserved.


## Install
```bash
pip install lishixian --upgrade
```


## Modules

### Top module
- help()

### Module 'cls'
- MyConfigParser(path, section)
- MyThread(target, *args, **kwargs)
- Tcp(addr='localhost', port=7010)

### Module 'decorator'
- timeit(f)
- tracer(f)
- protect(f)
- surround(before=(), after=())

### Module 'line'
- s128 = bytes(range(128)).decode()
- s127 = bytes(range(32, 127)).decode()
- empty(*v, **kv)
- t(arr)
- md5(b)
- start(func, *args, **kwargs)
- create(file)
- pprint(*value, file=sys.stdout)
- dumps(data)
- sort_kv(d, reverse=False)
- sort_key(d, reverse=False)
- sort_num(s)
- raw2headers(s)
- str2dict(s)
- unique(p, dash='-')
- pc_ip()
- pc_mac()
- pc_user()
- randombytes(n)
- tuple2item(item)
- join(path, *paths)

### Module 'refact'
- infinity = <class 'itertools.count'>
- makedirs(name, mode=511, *, exist_ok=True)
- breakpoint()
- popen(cmd)
- listdir(*paths)
- findall(pattern, string, flags=0)
- split(arr, cols)
- print(*value, **kwargs)
- splitpath(p)
- walk(path, exts=())
- open(file)

### Module 'useful'
- tag()
- log(*value)
- check(obj, rule=<class 'bool'>)
- safe_name(filename, repl=' ')
- escape(s, quote=True)
- unescape(s)
- quote(string, safe='', encoding=None, errors=None)
- unquote(string, encoding='utf-8', errors='replace')
- urlopen(url, timeout=5)
- findpair(s, p1='(', p2=')', st=0)
- bytes_format(data, n=16)
- bytes_print(data, n=16)
- bytes_hex(data, offset=0, length=-1, slice=-1)
- argv_run(func, *defaults)
- install(path, block=False)
- input_wait(msg)
- input_default(msg, default)
- Catch(log='log.txt')
- catch = <Catch object>
- MaxThread(max)

### Module 'windll'
- MessageBox(info, title='Message', style=0)
- DirDialog(message=None)
- OpenFileDialog(title=None, filter='', path='')
- SaveFileDialog(title=None, filter='', path='')

### Module 'auto'
- shortcut(p=None, make=True)
- copy(word, tab=0)
- Monitor(func)
- Recoder(complete=False)

### Module 'doc'
- WriteTxt(data, file, encoding='utf-8-sig')
- ReadCsv(file, encoding='utf-8-sig')
- WriteCsv(data, file, encoding='utf-8-sig', errors='ignore')
- WriteExcel(data, file, new_sheet='sheet1')
- OpenExcel(file)
- MergeCell(data, merge, merge_x=True, merge_y=True, strip_x=False)
- ReadExcel(file, merge_x=True, merge_y=True, strip_x=False)
- ReadSheet(file, index=0)
- Doc2Docx(file, overwrite=False)
- OpenDocx(file)
- ReadWordTexts(file)
- ReadWord(file, merge_x=True, merge_y=True, strip_x=False)
- ReadFile(file, merge_x=True, merge_y=True, strip_x=False)
- File2Csv(file, merge_x=True, merge_y=True, strip_x=False)
- ReadFiles(files, merge_x=True, merge_y=True, strip_x=False)
- Unique(arr)

### Module 'gui'
- center(top)
- WrapBox(parent, w, label='')
- GetClipboard()
- SetClipboard(text)
- Mover(parent, widget)
- EventThread(parent, id, target=<class 'bool'>, *args, **kwargs)

### Module 'np'
- imread(file)
- imwrite(file, im)
- imshow(img, delay=50, title='')
- imsave(file)
- imiter(file_or_id, st=None, ed=None)


## Comment
1. Lib `lsx` is same as `lishixian` in `pypi.org`.
2. If you **really** need domain `lsx` in `pypi.org`, contact me with `Email`.

==> lsx-0.2.4.tar.gz: lsx-0.2.4/lsx/docs/readme.md <==
# Lite Software eXtension

Contain 11 modules and 127 functions.


## About
- __Author:__ Lishixian
- __QQ:__ 11313213
- __Email:__ lsx7@sina.com
- __Github:__ https://github.com/znsoooo/lishixian
- __License:__ MIT License. Copyright (c) 2022 Lishixian (znsoooo). All Rights Reserved.


## Install
```bash
pip install lishixian --upgrade
```


## Usage
```python
import lishixian as lsx
lsx.help()
```


## Modules

### Top module
- all()
- help()

### Module 'cls'
- Config(path, section='default', encoding='u8')
- Thread(target, *args, **kwargs)
- Tcp(addr, port)
- Udp(addr, port)

### Module 'dec'
- main(f)
- timeit(f)
- tracer(f)
- protect(f)
- surround(before=(), after=())
- hotkey(key='F12')
- threads(cnt)

### Module 'new'
- print(*value, file=<_io.TextIOWrapper name='<stdout>' mode='w' encoding='UTF-8'>)
- time(start=0)
- infinity = <class 'itertools.count'>
- makedirs(name, mode=511, *, exist_ok=True)
- breakpoint()
- popen(cmd)
- listdir(*paths)
- findall(pattern, string, flags=0)
- split(arr, cols)
- pack(fmt, values)
- unpack(fmt, string)
- detect(file)
- walk(paths='.', exts='')
- open(file)

### Module 'reg'
- GetDir(name, local=False)
- DeleteRecu(key)
- DeleteKey(key, name='')
- SetKey(key, name='', val='')
- NewFilePy()

### Module 'line'
- s128 = bytes(range(128)).decode()
- s127 = bytes(range(32, 127)).decode()
- empty(*v, **kv)
- freeze(fn, *v, **kv)
- t(arr)
- crc(b)
- md5(b)
- mask(p)
- start(func, *args, **kwargs)
- create(file)
- pprint(*value, file=sys.stdout)
- dumps(data)
- sort_kv(d, reverse=False)
- sort_key(d, reverse=False)
- sort_num(s)
- str2dict(s)
- tuple2item(item)
- unique(arr)
- flatten(arr)
- reshape(arr, width)
- pc_ip()
- pc_mac()
- pc_user()
- randombytes(n)
- join(*s, sp='')

### Module 'useful'
- pause()
- log(*value, file='log.txt')
- progress(*value, interval=1)
- check(obj, patt='.*', stdout=True)
- fps()
- ext(p)
- stem(p)
- select(path)
- path_mark(path, mark='.bak')
- path_safe(p, repl=None)
- path_split(p)
- path_unique(p, dash='-')
- file_mtime(path)
- file_ctime(path)
- file_utime(path, date)
- factorize(num)
- primes(max)
- escape(s, quote=True)
- unescape(s)
- quote(string, safe='', encoding=None, errors=None)
- unquote(string, encoding='utf-8', errors='replace')
- urlopen(url, timeout=5)
- scan(format, string)
- findpair(s, p1='(', p2=')', st=0)
- bytes_format(data, n=16)
- bytes_print(data, n=16)
- bytes_hex(data, offset=0, length=-1, slice=-1)
- install(path, block=False)
- input_wait(msg)
- input_default(msg, default)
- Catch(log='log.txt')
- catch = <Catch object>

### Module 'windll'
- MessageBox(info, title='Message', style=0)
- DirDialog(message=None)
- OpenFileDialog(title=None, filter='', path='')
- SaveFileDialog(title=None, filter='', path='')

### Module 'auto'
- shortcut(p=None, make=True)
- copy(word, tab=0)
- Monitor(func)
- Recoder(complete=False)

### Module 'doc'
- read(file, encoding='u8')
- write(file, data, encoding='u8')
- ReadIni(file, encoding='u8')
- WriteIni(file, dic, encoding='u8')
- WriteTxt(file, data, encoding='utf-8-sig')
- ReadCsv(file, encoding='utf-8-sig')
- WriteCsv(file, data, encoding='utf-8-sig', errors='ignore')
- WriteExcel(file, data, new_sheet='sheet1')
- OpenExcel(file)
- MergeCell(data, merge, merge_x=True, merge_y=True, strip_x=False)
- ReadExcel(file, merge_x=True, merge_y=True, strip_x=False)
- ReadSheet(file, index=0)
- Doc2Docx(file, overwrite=False)
- OpenDocx(file)
- ReadWordTexts(file)
- ReadWord(file, merge_x=True, merge_y=True, strip_x=False)
- ReadFile(file, merge_x=True, merge_y=True, strip_x=False)
- File2Csv(file, merge_x=True, merge_y=True, strip_x=False)
- ReadFiles(files, merge_x=True, merge_y=True, strip_x=False)

### Module 'gui'
- center(top)
- WrapBox(parent, w, label='')
- GetClipboard()
- SetClipboard(text)
- Mover(parent, widget)
- EventThread(parent, id, target=<class 'bool'>, *args, **kwargs)

### Module 'np'
- imread(file)
- imwrite(file, im)
- imshow(img, delay=50, title='')
- imsave(file)
- imiter(file_or_id)


## Comment
1. Lib `lsx` is same as `lishixian` in `pypi.org`.
2. If you **really** need domain `lsx` in `pypi.org`, contact me with `Email`.
